==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/sessionnegotiation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>SessionNegotiation</name>
    <message>
        <source>Session Negotiation</source>
        <translation>Согласование сессии</translation>
    </message>
    <message>
        <source>Negotiate session requests</source>
        <translation>Запросы установки сессии</translation>
    </message>
    <message>
        <source>Negotiate Session</source>
        <translation>Согласовать сессию</translation>
    </message>
    <message>
        <source>Terminate Session</source>
        <translation>Разорвать сессию</translation>
    </message>
    <message>
        <source>Allow multiple sessions?</source>
        <translation>Разрешить множественные сессии?</translation>
    </message>
    <message>
        <source>Session negotiation</source>
        <translation>Согласование сессии</translation>
    </message>
    <message>
        <source>Accept this session?</source>
        <translation>Разрешить сессию?</translation>
    </message>
    <message>
        <source>Accept the Invitation?</source>
        <translation>Принять приглашение?</translation>
    </message>
    <message>
        <source>Another Resource</source>
        <translation>Другой ресурс</translation>
    </message>
    <message>
        <source>Disclosure of Content</source>
        <translation>Раскрытие содержания</translation>
    </message>
    <message>
        <source>Enable Chat State Notifications?</source>
        <translation>Разрешить уведомления о статусе чата?</translation>
    </message>
    <message>
        <source>Enable XHTML-IM formatting?</source>
        <translation>Разрешить XHTML-IM форматирование?</translation>
    </message>
    <message>
        <source>Primary Written Language of the Chat</source>
        <translation>Основной язык переписки в чате</translation>
    </message>
    <message>
        <source>Enable Message Loggings?</source>
        <translation>Разрешить протоколирование сообщений?</translation>
    </message>
    <message>
        <source>Renegotiate the Session?</source>
        <translation>Пересогласовать сессию?</translation>
    </message>
    <message>
        <source>Minimum Security Level</source>
        <translation>Минимальный уровень безопасности</translation>
    </message>
    <message>
        <source>Terminate the Session?</source>
        <translation>Разорвать сессию?</translation>
    </message>
    <message>
        <source>Enable Message Receipts?</source>
        <translation>Разрешить уведомления о доставке?</translation>
    </message>
    <message>
        <source>Session renegotiation</source>
        <translation>Пересогласование сессии</translation>
    </message>
    <message>
        <source>Session negotiation - %1</source>
        <translation>Пересогласование сессии - %1</translation>
    </message>
    <message>
        <source>Set desirable session settings.</source>
        <translation>Установите желаемые настройки сессии.</translation>
    </message>
    <message>
        <source>Do you accept this session settings?</source>
        <translation>Вы согласны с настройками сессии?</translation>
    </message>
    <message>
        <source>Renegotiate this session?</source>
        <translation>Пересогласовать сессию?</translation>
    </message>
    <message>
        <source>Jabber Session Manager</source>
        <translation>Диспетчер джаббер сессий</translation>
    </message>
    <message>
        <source>Allows to set the session between two entities, which explains the rules of the exchange of XMPP stanzas</source>
        <translation>Позволяет устанавливать сессию между двумя сущностями, которая определяет правила обмена XMPP строфами</translation>
    </message>
    <message>
        <source>Supports the negotiating of the stanza session between two XMPP entities</source>
        <translation>Поддерживает инициализацию сессии строф между двумя XMPP сущностями</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/sessionnegotiation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>SessionNegotiation</name>
    <message>
        <source>Session Negotiation</source>
        <translation>Согласование сессии</translation>
    </message>
    <message>
        <source>Negotiate Session</source>
        <translation>Согласовать сессию</translation>
    </message>
    <message>
        <source>Terminate Session</source>
        <translation>Разорвать сессию</translation>
    </message>
    <message>
        <source>Allow multiple sessions?</source>
        <translation>Разрешить множественные сессии?</translation>
    </message>
    <message>
        <source>Session negotiation</source>
        <translation>Согласование сессии</translation>
    </message>
    <message>
        <source>Accept this session?</source>
        <translation>Разрешить сессию?</translation>
    </message>
    <message>
        <source>Accept the Invitation?</source>
        <translation>Принять приглашение?</translation>
    </message>
    <message>
        <source>Another Resource</source>
        <translation>Другой ресурс</translation>
    </message>
    <message>
        <source>Disclosure of Content</source>
        <translation>Раскрытие содержания</translation>
    </message>
    <message>
        <source>Enable Chat State Notifications?</source>
        <translation>Разрешить уведомления о статусе чата?</translation>
    </message>
    <message>
        <source>Enable XHTML-IM formatting?</source>
        <translation>Разрешить XHTML-IM форматирование?</translation>
    </message>
    <message>
        <source>Primary Written Language of the Chat</source>
        <translation>Основной язык переписки в чате</translation>
    </message>
    <message>
        <source>Enable Message Loggings?</source>
        <translation>Разрешить протоколирование сообщений?</translation>
    </message>
    <message>
        <source>Renegotiate the Session?</source>
        <translation>Пересогласовать сессию?</translation>
    </message>
    <message>
        <source>Minimum Security Level</source>
        <translation>Минимальный уровень безопасности</translation>
    </message>
    <message>
        <source>Terminate the Session?</source>
        <translation>Разорвать сессию?</translation>
    </message>
    <message>
        <source>Enable Message Receipts?</source>
        <translation>Разрешить уведомления о доставке?</translation>
    </message>
    <message>
        <source>Session renegotiation</source>
        <translation>Пересогласование сессии</translation>
    </message>
    <message>
        <source>Session negotiation - %1</source>
        <translation>Пересогласование сессии - %1</translation>
    </message>
    <message>
        <source>Set desirable session settings.</source>
        <translation>Установите желаемые настройки сессии.</translation>
    </message>
    <message>
        <source>Do you accept this session settings?</source>
        <translation>Вы согласны с настройками сессии?</translation>
    </message>
    <message>
        <source>Renegotiate this session?</source>
        <translation>Пересогласовать сессию?</translation>
    </message>
    <message>
        <source>Jabber Session Manager</source>
        <translation>Диспетчер джаббер сессий</translation>
    </message>
    <message>
        <source>Allows to set the session between two entities, which explains the rules of the exchange of XMPP stanzas</source>
        <translation>Позволяет устанавливать сессию между двумя сущностями, которая определяет правила обмена XMPP строфами</translation>
    </message>
    <message>
        <source>Supports the negotiating of the stanza session between two XMPP entities</source>
        <translation>Поддерживает инициализацию сессии строф между двумя XMPP сущностями</translation>
    </message>
    <message>
        <source>When receiving session negotiation request</source>
        <translation>При получении запроса установки сессии</translation>
    </message>
</context>
</TS>
